@@ -66,6 +66,56 @@ class Executor:
         """
         return Transformation(self.apikey, self.host, name)
 
+    def create_lookup_set(self, name):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+
+        requests.post(self.host+"/api/lookup/table?table="+name, headers=headers)
+
+
+    def delete_lookup_set(self, name):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+
+        requests.delete(self.host + "/api/lookup/table?table=" + name, headers=headers)
+
+    def list_lookup_sets(self):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+
+        requests.get(self.host + "/api/lookup/table", headers=headers)
+
+    def add_to_lookup(self, table, key, value):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+        data = {
+            "key": key,
+            "value": value
+        }
+
+        requests.post(self.host + "/api/lookup/values?table="+table, data=json.dumps(data), headers=headers)
+
+    def delete_from_lookup(self, table, key):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+        data = {
+            "key": key,
+        }
+
+        requests.delete(self.host + "/api/lookup/values?table="+table, data=json.dumps(data), headers=headers)
+
+    def list_lookup_values(self, table):
+        headers = {
+            'X-StreamSQL-Admin-Key': self.apikey
+        }
+
+        requests.get(self.host + "/api/lookup/values?table="+table, headers=headers)
+
     def deregister_transformation(self, name):
         """
         Deregisters a transformation
@@ -262,6 +312,7 @@ class Transformation:
         self.apikey = apikey
         self.host = host
         self.name = name
+        self.__lookup = {'enabled':'false'}
 
     def source(self, name, type=ResourceTypes.Stream):
         """
@@ -330,6 +381,16 @@ class Transformation:
         self.fields.append(self.field(raw, alias, type))
         return self
 
+    def lookup(self, table, field):
+        self.__lookup = {}
+        self.__lookup['enabled'] = "true"
+        self.__lookup['field'] = field
+        self.__lookup['name'] = table
+        return self
+
+
+
+
     def commit(self):
         """
         Validates configuration then builds and sends
@@ -388,6 +449,7 @@ class Transformation:
         payload['source'] = self.source_tbl.build()
         payload['sink'] = self.sink_tbl.build()
         payload['query'] = self._build_query()
+        payload['lookup'] = self.__lookup
 
         return payload
 
